Struct Mat3x2
Source #[repr(C)]
pub struct Mat3x2<T> {
pub x: Vec2<T>,
pub y: Vec2<T>,
pub z: Vec2<T>,
}
Matrix with 3 columns and 2 rows.
The matrix is stored column-major; that is, each field is a whole column of the matrix.
Performs component-wise addition.
The resulting type after applying the + operator.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
The returned type after indexing.
Performs the indexing (
container[index]) operation.
Read more
The returned type after indexing.
Performs the indexing (
container[index]) operation.
Read more
The returned type after indexing.
Performs the indexing (
container[index]) operation.
Read more
Performs the mutable indexing (
container[index]) operation.
Read more
Performs the mutable indexing (
container[index]) operation.
Read more
Performs the mutable indexing (
container[index]) operation.
Read more
Performs matrix multiplication.
The resulting type after applying the * operator.
Performs component-wise multiplication by a scalar.
The resulting type after applying the * operator.
Multiplication with vector on the left and matrix on the right.
The resulting type after applying the * operator.
Performs matrix multiplication.
The resulting type after applying the * operator.
Performs matrix multiplication.
The resulting type after applying the * operator.
Performs matrix multiplication.
The resulting type after applying the * operator.
Performs matrix multiplication.
The resulting type after applying the * operator.
Performs matrix multiplication.
The resulting type after applying the * operator.
Performs component-wise multiplication by a scalar.
The resulting type after applying the * operator.
Multiplication with matrix on the left and vector on the right.
The resulting type after applying the * operator.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Performs component-wise subtraction.
The resulting type after applying the - operator.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.