Vec4

Struct Vec4 

#[repr(C)]
pub struct Vec4<T> { pub x: T, pub y: T, pub z: T, pub w: T, }

Fields

x: Ty: Tz: Tw: T

Implementations

Source

impl<T> Vec4<T>

pub fn splat(value: T) -> Self
where T: Copy,

pub fn splat_from_scalar(value: Scalar<T>) -> Self
where T: Copy,

pub const fn select(self, trues: Self, mask: Vec4<bool>) -> Self
where T: Copy,

Replaces the elements of self with the elements of trues wherever mask contains true.

pub fn map<U, F>(self, f: F) -> Vec4<U>
where F: FnMut(T) -> U,

Source

impl Vec4<i32>

pub fn max(self, rhs: Self) -> Self

pub fn min(self, rhs: Self) -> Self

Source

impl Vec4<u32>

pub fn max(self, rhs: Self) -> Self

pub fn min(self, rhs: Self) -> Self

Source

impl Vec4<f32>

pub const fn clamp(self, low: Self, high: Self) -> Self

As per WGSL clamp().

pub fn distance(self, rhs: Self) -> f32

As per WGSL distance().

pub const fn dot(self, rhs: Self) -> f32

As per WGSL dot().

pub fn face_forward(self, e2: Self, e3: Self) -> Self

As per WGSL faceForward().

pub fn length(self) -> f32

As per WGSL length().

pub const fn mix(self, rhs: Self, blend: f32) -> Self

As per WGSL mix().

pub fn mul_add(self, b: Self, c: Self) -> Self

As per WGSL fma().

pub fn normalize(self) -> Self

As per WGSL normalize().

pub fn reflect(self, rhs: Self) -> Self

As per WGSL reflect().

pub const fn saturate(self) -> Self

As per WGSL saturate().

pub const fn sign(self) -> Self

As per WGSL sign().

pub const fn abs(self) -> Self

pub fn acos(self) -> Self

pub fn acosh(self) -> Self

pub fn asin(self) -> Self

pub fn asinh(self) -> Self

pub fn atan(self) -> Self

pub fn atanh(self) -> Self

pub fn ceil(self) -> Self

pub fn cos(self) -> Self

pub fn cosh(self) -> Self

pub fn exp(self) -> Self

pub fn exp2(self) -> Self

pub fn floor(self) -> Self

pub fn fract(self) -> Self

pub fn log2(self) -> Self

pub fn round(self) -> Self

pub fn sin(self) -> Self

pub fn sinh(self) -> Self

pub fn tan(self) -> Self

pub fn tanh(self) -> Self

pub fn trunc(self) -> Self

pub fn to_degrees(self) -> Self

pub fn to_radians(self) -> Self

pub fn atan2(self, rhs: Self) -> Self

pub fn max(self, rhs: Self) -> Self

pub fn min(self, rhs: Self) -> Self

pub fn powf(self, rhs: Self) -> Self

Source

impl Vec4<f64>

pub const fn clamp(self, low: Self, high: Self) -> Self

As per WGSL clamp().

pub fn distance(self, rhs: Self) -> f64

As per WGSL distance().

pub const fn dot(self, rhs: Self) -> f64

As per WGSL dot().

pub fn face_forward(self, e2: Self, e3: Self) -> Self

As per WGSL faceForward().

pub fn length(self) -> f64

As per WGSL length().

pub const fn mix(self, rhs: Self, blend: f64) -> Self

As per WGSL mix().

pub fn mul_add(self, b: Self, c: Self) -> Self

As per WGSL fma().

pub fn normalize(self) -> Self

As per WGSL normalize().

pub fn reflect(self, rhs: Self) -> Self

As per WGSL reflect().

pub const fn saturate(self) -> Self

As per WGSL saturate().

pub const fn sign(self) -> Self

As per WGSL sign().

pub const fn abs(self) -> Self

pub fn acos(self) -> Self

pub fn acosh(self) -> Self

pub fn asin(self) -> Self

pub fn asinh(self) -> Self

pub fn atan(self) -> Self

pub fn atanh(self) -> Self

pub fn ceil(self) -> Self

pub fn cos(self) -> Self

pub fn cosh(self) -> Self

pub fn exp(self) -> Self

pub fn exp2(self) -> Self

pub fn floor(self) -> Self

pub fn fract(self) -> Self

pub fn log2(self) -> Self

pub fn round(self) -> Self

pub fn sin(self) -> Self

pub fn sinh(self) -> Self

pub fn tan(self) -> Self

pub fn tanh(self) -> Self

pub fn trunc(self) -> Self

pub fn to_degrees(self) -> Self

pub fn to_radians(self) -> Self

pub fn atan2(self, rhs: Self) -> Self

pub fn max(self, rhs: Self) -> Self

pub fn min(self, rhs: Self) -> Self

pub fn powf(self, rhs: Self) -> Self

Source

impl Vec4<i32>

Source

impl Vec4<u32>

Source

impl Vec4<f32>

Source

impl Vec4<f64>

Source

impl<T: ConstZero> Vec4<T>

pub const ZERO: Self

Source

impl<T: PartialOrd> Vec4<T>

pub fn elementwise_eq(self, rhs: Self) -> Vec4<bool>

pub fn elementwise_ne(self, rhs: Self) -> Vec4<bool>

pub fn elementwise_lt(self, rhs: Self) -> Vec4<bool>

pub fn elementwise_le(self, rhs: Self) -> Vec4<bool>

pub fn elementwise_gt(self, rhs: Self) -> Vec4<bool>

pub fn elementwise_ge(self, rhs: Self) -> Vec4<bool>

Source

impl Vec4<i32>

pub const fn abs(self) -> Self

Source

impl Vec4<u32>

pub fn abs(self) -> Self

Source

impl<T> Vec4<T>

pub const fn new(x: T, y: T, z: T, w: T) -> Self

pub const fn from_scalars( x: Scalar<T>, y: Scalar<T>, z: Scalar<T>, w: Scalar<T>, ) -> Self
where T: Copy,

Source

impl<T: Copy> Vec4<T>

pub const fn new_112(x: T, y: T, zw: Vec2<T>) -> Self

pub const fn new_121(x: T, yz: Vec2<T>, w: T) -> Self

pub const fn new_211(xy: Vec2<T>, z: T, w: T) -> Self

pub const fn new_22(xy: Vec2<T>, zw: Vec2<T>) -> Self

pub const fn new_13(x: T, yzw: Vec3<T>) -> Self

pub const fn new_31(xyz: Vec3<T>, w: T) -> Self

Source

impl<T: Copy> Vec4<T>

pub fn xy(self) -> Vec2<T>

Takes the x, y elements of self and returns them in that order.

pub fn yx(self) -> Vec2<T>

Takes the y, x elements of self and returns them in that order.

pub fn xyz(self) -> Vec3<T>

Takes the x, y, z elements of self and returns them in that order.

pub fn xzy(self) -> Vec3<T>

Takes the x, z, y elements of self and returns them in that order.

pub fn yxz(self) -> Vec3<T>

Takes the y, x, z elements of self and returns them in that order.

pub fn yzx(self) -> Vec3<T>

Takes the y, z, x elements of self and returns them in that order.

pub fn zxy(self) -> Vec3<T>

Takes the z, x, y elements of self and returns them in that order.

pub fn zyx(self) -> Vec3<T>

Takes the z, y, x elements of self and returns them in that order.

pub fn xyzw(self) -> Vec4<T>

Takes the x, y, z, w elements of self and returns them in that order.

pub fn xywz(self) -> Vec4<T>

Takes the x, y, w, z elements of self and returns them in that order.

pub fn xzwy(self) -> Vec4<T>

Takes the x, z, w, y elements of self and returns them in that order.

pub fn xzyw(self) -> Vec4<T>

Takes the x, z, y, w elements of self and returns them in that order.

pub fn xwyz(self) -> Vec4<T>

Takes the x, w, y, z elements of self and returns them in that order.

pub fn xwzy(self) -> Vec4<T>

Takes the x, w, z, y elements of self and returns them in that order.

pub fn yxzw(self) -> Vec4<T>

Takes the y, x, z, w elements of self and returns them in that order.

pub fn yxwz(self) -> Vec4<T>

Takes the y, x, w, z elements of self and returns them in that order.

pub fn yzxw(self) -> Vec4<T>

Takes the y, z, x, w elements of self and returns them in that order.

pub fn yzwx(self) -> Vec4<T>

Takes the y, z, w, x elements of self and returns them in that order.

pub fn ywzx(self) -> Vec4<T>

Takes the y, w, z, x elements of self and returns them in that order.

pub fn ywxz(self) -> Vec4<T>

Takes the y, w, x, z elements of self and returns them in that order.

pub fn zxyw(self) -> Vec4<T>

Takes the z, x, y, w elements of self and returns them in that order.

pub fn zxwy(self) -> Vec4<T>

Takes the z, x, w, y elements of self and returns them in that order.

pub fn zyxw(self) -> Vec4<T>

Takes the z, y, x, w elements of self and returns them in that order.

pub fn zywx(self) -> Vec4<T>

Takes the z, y, w, x elements of self and returns them in that order.

pub fn zwxy(self) -> Vec4<T>

Takes the z, w, x, y elements of self and returns them in that order.

pub fn zwyx(self) -> Vec4<T>

Takes the z, w, y, x elements of self and returns them in that order.

pub fn wxyz(self) -> Vec4<T>

Takes the w, x, y, z elements of self and returns them in that order.

pub fn wxzy(self) -> Vec4<T>

Takes the w, x, z, y elements of self and returns them in that order.

pub fn wyxz(self) -> Vec4<T>

Takes the w, y, x, z elements of self and returns them in that order.

pub fn wyzx(self) -> Vec4<T>

Takes the w, y, z, x elements of self and returns them in that order.

pub fn wzxy(self) -> Vec4<T>

Takes the w, z, x, y elements of self and returns them in that order.

pub fn wzyx(self) -> Vec4<T>

Takes the w, z, y, x elements of self and returns them in that order.