Texture2dArray

Struct Texture2dArray 

pub struct Texture2dArray<T: ?Sized> {
    pub dimensions: Vec2<NonZeroU32>,
    pub array_layers: NonZeroU32,
    pub mip_levels: NonZeroU32,
    pub data: T,
}
2-dimensional array texture object.

Use this type to satisfy a texture binding in a resource struct, when the binding has WGSL type texture_2d_array.

Fields

dimensions: Vec2<NonZeroU32>array_layers: NonZeroU32mip_levels: NonZeroU32data: T