pub struct TextureCube<T: ?Sized> {
pub dimensions: Vec2<NonZeroU32>,
pub mip_levels: NonZeroU32,
pub data: T,
}Expand description
Cubemap texture object.
Use this type to satisfy a texture binding in a resource struct,
when the binding has WGSL type texture_cube.
Fields
dimensions: Vec2<NonZeroU32>mip_levels: NonZeroU32data: TTrait Implementations
Sourceimpl<T: Clone + ?Sized> Clone for TextureCube<T>
impl<T: Clone + ?Sized> Clone for TextureCube<T>
Sourcefn clone(&self) -> TextureCube<T>
fn clone(&self) -> TextureCube<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: PartialEq + ?Sized> PartialEq for TextureCube<T>
impl<T: PartialEq + ?Sized> PartialEq for TextureCube<T>
Sourcefn eq(&self, other: &TextureCube<T>) -> bool
fn eq(&self, other: &TextureCube<T>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<T: ?Sized + Read> Query for TextureCube<T>
impl<T: ?Sized + Read> Query for TextureCube<T>
Sourcefn base_dimensions(&self) -> Self::Dimensions
fn base_dimensions(&self) -> Self::Dimensions
Returns the dimensions of mip level 0 of the texture.
Sourcefn mip_levels(&self) -> NonZeroU32
fn mip_levels(&self) -> NonZeroU32
Returns the count of mip levels of the texture.
Sourcefn array_layers(&self) -> NonZeroU32
fn array_layers(&self) -> NonZeroU32
Returns the count of array layers of the texture. Read more
Sourcefn samples(&self) -> NonZeroU32
fn samples(&self) -> NonZeroU32
Returns the count of samples of the texture. Read more
Sourceimpl<T: ?Sized + Read> Read for TextureCube<T>
impl<T: ?Sized + Read> Read for TextureCube<T>
type Coordinates = <T as Read>::Coordinates
type Component = <T as Read>::Component
Sourcefn read_texel(
&self,
coordinates: Self::Coordinates,
array_layer: i32,
sample: i32,
mip_level: i32,
) -> Vec4<Self::Component>
fn read_texel( &self, coordinates: Self::Coordinates, array_layer: i32, sample: i32, mip_level: i32, ) -> Vec4<Self::Component>
Loads a single texel from the texture. Read more
impl<T: Copy + ?Sized> Copy for TextureCube<T>
impl<T: Eq + ?Sized> Eq for TextureCube<T>
impl<T: ?Sized> StructuralPartialEq for TextureCube<T>