pub trait Read {
type Coordinates: Copy + 'static;
type Component: Component;
// Required method
fn read_texel(
&self,
coordinates: Self::Coordinates,
array_layer: i32,
sample: i32,
mip_level: i32,
) -> Vec4<Self::Component>;
}Expand description
Required Associated Types
Required Methods
Sourcefn read_texel(
&self,
coordinates: Self::Coordinates,
array_layer: i32,
sample: i32,
mip_level: i32,
) -> Vec4<Self::Component>
fn read_texel( &self, coordinates: Self::Coordinates, array_layer: i32, sample: i32, mip_level: i32, ) -> Vec4<Self::Component>
Loads a single texel from the texture.
If the coordinates are out of bounds, the implementation should not panic, but perform one of the behaviors specified in https://www.w3.org/TR/WGSL/#textureload.