pub fn zero<T: Default>() -> TExpand description
Returns the WGSL zero value of a type.
Conveniently, all of the types for which this is defined also implement Default to return
zero, so this is actually an alias for Default::default().
pub fn zero<T: Default>() -> TReturns the WGSL zero value of a type.
Conveniently, all of the types for which this is defined also implement Default to return
zero, so this is actually an alias for Default::default().